@@ -1,23 +1,11 @@
 import json
-from six import string_types
-from importlib import import_module
 
-from django.conf import settings
 from rest_framework import exceptions
 from channels.generic.websocket import AsyncWebsocketConsumer
 from channels.db import database_sync_to_async
 
-from chit_chat.consumer_serializers import ChatMessageSerializer, ContentSerializer
-
-
-def import_callable(path_or_callable):
-    if hasattr(path_or_callable, '__call__'):
-        return path_or_callable
-    else:
-        assert isinstance(path_or_callable, string_types)
-        package, attr = path_or_callable.rsplit('.', 1)
-        print('package', package)
-        return getattr(import_module(package), attr)
+from chit_chat.consumer_serializers import ContentSerializer
+from .ckc_conf import chat_settings
 
 
 def async_validation_exception_handler(func):
@@ -47,15 +35,18 @@ class ChatRoomConsumer(AsyncWebsocketConsumer):
         if not user.is_authenticated:
             await self.close()
             return
-        for pk in await self.get_chat_room_pks(user):
-            await self.channel_layer.group_add(str(pk), self.channel_name)
+
+        await self.enter_rooms()
+
+        # Allows us to easily send targeted messages to this user throughout the app.
+        await self.channel_layer.group_add(f'user-{user.pk}', self.channel_name)
         await self.accept()
 
     async def disconnect(self, close_code):
         user = self.scope['user']
         if user.is_authenticated:
-            for pk in await self.get_chat_room_pks(self.scope['user']):
-                await self.channel_layer.group_discard(str(pk), self.channel_name)
+            await self.exit_rooms()
+            await self.channel_layer.group_discard(f'user-{user.pk}', self.channel_name)
 
     async def receive(self, text_data=None, bytes_data=None):
         user = self.scope['user']
@@ -86,6 +77,14 @@ class ChatRoomConsumer(AsyncWebsocketConsumer):
                         }
                     )
 
+    async def enter_rooms(self):
+        for pk in await self.get_chat_room_pks(self.scope['user']):
+            await self.channel_layer.group_add(str(pk), self.channel_name)
+
+    async def exit_rooms(self):
+        for pk in await self.get_chat_room_pks(self.scope['user']):
+            await self.channel_layer.group_discard(str(pk), self.channel_name)
+
     @async_validation_exception_handler
     async def validate_content(self, data):
         serializer = ContentSerializer(ChatRoomConsumer.MESSAGE_TYPES, data=data)
@@ -94,11 +93,7 @@ class ChatRoomConsumer(AsyncWebsocketConsumer):
     @async_validation_exception_handler
     @database_sync_to_async
     def validate_chat_message(self, data):
-        serializers = getattr(settings, 'CKC_CHAT_SERIALIZERS', {})
-        chat_serializer = import_callable(
-            serializers.get('CHAT_MESSAGE_SERIALIZER', ChatMessageSerializer)
-        )
-        serializer = chat_serializer(data=data)
+        serializer = chat_settings['SERIALIZERS'].MESSAGE(data=data)
         serializer.is_valid(raise_exception=True)
         return serializer.save()
 
@@ -113,6 +108,9 @@ class ChatRoomConsumer(AsyncWebsocketConsumer):
             })
         )
 
+    async def refresh_group_add(self, _):
+        await self.enter_rooms()
+
     @database_sync_to_async
     def get_chat_room_pks(self, user):
         return list(user.chat_rooms.values_list('pk', flat=True))
